@@ -1,10 +1,10 @@
 
-/* prvdump.c (dump private key) - Mark Henderson (markh@wimsey.bc.ca) */
-
+/* prvdump.c (dump private key) - Mark Henderson (markh@wimsey.bc.ca) 
+   also does a few interesting computations */
 #include "l3.h"
 main(int argc, char *argv[])
 {
-	MP_INT *e, *p, *q, *c, *n, *d;
+	MP_INT *e, *p, *q, *c, *n, *d, *pa, *qa;
 	char *ps, *qs, *es, *ds;
 	char prvfile[127];
 	int i;
@@ -22,6 +22,8 @@ main(int argc, char *argv[])
 	init(c);
 	init(n);
 	init(d);
+	init(pa);
+	init(qa);
 	if (argc < 2) {
 		fprintf(stderr, "usage: prvdump prvfile\n");
 		exit(1);
@@ -59,13 +61,34 @@ main(int argc, char *argv[])
 	printf("q=%s\n", qs);
 	es = mpz_get_str(NULL, 16, e);
 	printf("e=%s\n", es);
-	mpz_sub_ui(p, p, 1);
-	mpz_sub_ui(q, q, 1);
-	mpz_mul(p, p, q);
-	modinv(d, e, p);	/* calculate d for RSA for fun */
+	mpz_sub_ui(pa, p, 1);
+	mpz_sub_ui(qa, q, 1);
+	mpz_mul(c, pa, qa);
+	modinv(d, e, c);	/* calculate d for RSA for fun */
 	ds = mpz_get_str(NULL, 16, d);
-	printf("RSA\nd=%s\n", ds);
+	printf("RSA d=%s\n", ds);
+
+	mpz_gcd(c,pa,qa);
+	ds = mpz_get_str(NULL, 16, c);
+	printf("gcd(p-1,q-1)=%s\n", ds);
+	
+	mpz_add_ui(pa,p,1);
+	mpz_gcd(c,pa,qa);
+	ds = mpz_get_str(NULL, 16, c);
+	printf("gcd(p+1,q-1)=%s\n", ds);
+
+	mpz_add_ui(qa,q,1);
+	mpz_gcd(c,pa,qa);
+	ds = mpz_get_str(NULL, 16, c);
+	printf("gcd(p+1,q+1)=%s\n", ds);
+
+	mpz_sub_ui(pa,p,1);
+	mpz_gcd(c,pa,qa);
+	ds = mpz_get_str(NULL, 16, c);
+	printf("gcd(p-1,q+1)=%s\n", ds);
 	zap(k, 16);
 	zap(hash, 16);
 	zap(ss, strlen(ss));
+	clear(e); clear(p); clear(q); clear(c); clear(n); clear(d); clear(pa);
+	clear(qa);
 }
